@@ -11,13 +11,13 @@ def does_not_raise():
     yield
 
 
-def fixture_path(filename: str) -> str:
+def fixture_path(filename: str = "") -> str:
     return FIXTURE_PATH.joinpath(filename).as_posix()
 
 
-def config_path(filename: str) -> str:
+def config_path(filename: str = "") -> str:
     return CONFIG_PATH.joinpath(filename).as_posix()
 
 
-def rule_path(filename: str) -> str:
+def rule_path(filename: str = "") -> str:
     return RULE_PATH.joinpath(filename).as_posix()
