@@ -1,6 +1,8 @@
 import pytest
 
 from whispers import core
+from whispers.cli import parse_args
+from whispers.secrets import WhisperSecrets
 
 from .conftest import CONFIG_PATH, FIXTURE_PATH, config_path, fixture_path
 
@@ -8,8 +10,9 @@ from .conftest import CONFIG_PATH, FIXTURE_PATH, config_path, fixture_path
 @pytest.mark.parametrize("configfile", ["exclude_keys.yml", "exclude_values.yml"])
 @pytest.mark.parametrize("src", ["excluded.yml", "excluded.json", "excluded.xml"])
 def test_exclude_by_keys_and_values(configfile, src):
-    config = core.load_config(config_path(configfile), FIXTURE_PATH)
-    secrets = core.run(fixture_path(src), config=config)
+    args = parse_args([fixture_path(src)])
+    args.config = core.load_config(config_path(configfile), FIXTURE_PATH)
+    secrets = core.run(args)
     assert next(secrets).key == "hardcoded_password"
     with pytest.raises(StopIteration):
         next(secrets)
@@ -30,7 +33,8 @@ def test_exclude_by_keys_and_values(configfile, src):
     ],
 )
 def test_detection_by_key(src, keys):
-    secrets = core.run(fixture_path(src))
+    args = parse_args([fixture_path(src)])
+    secrets = core.run(args)
     for key in keys:
         assert next(secrets).key == key
     with pytest.raises(StopIteration):
@@ -66,23 +70,30 @@ def test_detection_by_key(src, keys):
         ("settings.cfg", 1),
         ("settings.ini", 1),
         ("settings.env", 1),
-        ("shell.sh", 14),
         ("Dockerfile", 3),
         ("beans.xml", 3),
+        ("beans.xml.dist", 3),
+        ("beans.xml.template", 3),
         ("jdbc.xml", 3),
         (".htpasswd", 2),
         (".aws/credentials", 3),
         ("falsepositive.yml", 4),
-        ("source.py", 5),
+        ("language.sh", 14),
+        ("language.py", 9),
+        ("language.js", 4),
+        ("language.java", 3),
+        ("language.go", 9),
+        ("language.php", 4),
         ("plaintext.txt", 2),
         ("uri.yml", 2),
         ("java.properties", 3),
-        ("webhooks.yml", 1),
+        ("webhooks.yml", 3),
     ],
 )
 def test_detection_by_value(src, count):
-    config = core.load_config(CONFIG_PATH.joinpath("detection_by_value.yml"))
-    secrets = core.run(fixture_path(src), config)
+    args = parse_args([fixture_path(src)])
+    args.config = core.load_config(CONFIG_PATH.joinpath("detection_by_value.yml"))
+    secrets = core.run(args)
     for _ in range(count):
         value = next(secrets).value.lower()
         if value.isnumeric():
@@ -109,8 +120,40 @@ def test_detection_by_filename():
             "settings.ini",
         ],
     )
-    config = core.load_config(CONFIG_PATH.joinpath("detection_by_filename.yml"))
-    secrets = core.run(fixture_path(""), config)
+    args = parse_args([fixture_path()])
+    args.config = core.load_config(CONFIG_PATH.joinpath("detection_by_filename.yml"))
+    secrets = core.run(args)
     result = [secret.value for secret in secrets]
     for exp in expected:
         assert exp in result
+
+
+@pytest.mark.parametrize(
+    ("key", "value", "expectation"),
+    [
+        (None, None, False),
+        ("", "", False),
+        ("", "$value", False),
+        ("", "{{value}}", False),
+        ("", "{value}", False),
+        ("", "{whispers~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~}", False),
+        ("", "{d2hpc3BlcnN+fn5+fn5+fn5+fn5+fn5+fn5+fn5+fn5+fn5+fn5+fn5+}", True),
+        ("", "${value$}", False),
+        ("", "<value>", False),
+        ("", "{value}", False),
+        ("", "null", False),
+        ("", "!Ref Value", False),
+        ("", "{value}", False),
+        ("", "/path/value", False),
+        ("whispers", "WHISPERS", False),
+        ("label", "WhispersLabel", False),
+        ("SECRET_VALUE_KEY", "whispers", False),
+        ("whispers", "SECRET_VALUE_PLACEHOLDER", False),
+        ("secret", "whispers", True),
+    ],
+)
+def test_is_static(key, value, expectation):
+    args = parse_args([fixture_path()])
+    args.config = core.load_config(CONFIG_PATH.joinpath("example.yml"))
+    secrets = WhisperSecrets(args)
+    assert secrets.is_static(key, value) == expectation
