@@ -1,12 +1,17 @@
 import logging
 import logging.config
 import traceback
+from os import remove
 from pathlib import Path
 
 
-def configure_log(path: str = ""):
-    path = Path(path, "whispers.log")
-    path.write_text("")
+def configure_log(logpath: str = "") -> Path:
+    try:
+        logpath = Path(logpath, "whispers.log")
+        logpath.write_text("")
+    except Exception:
+        debug(f"{logpath} is not valid")
+        raise ValueError
     logging.config.dictConfig(
         {
             "version": 1,
@@ -24,7 +29,7 @@ def configure_log(path: str = ""):
                     "level": "DEBUG",
                     "class": "logging.handlers.WatchedFileHandler",
                     "formatter": "default",
-                    "filename": path.as_posix(),
+                    "filename": logpath.as_posix(),
                     "mode": "w",
                     "encoding": "utf-8",
                 }
@@ -32,6 +37,16 @@ def configure_log(path: str = ""):
             "loggers": {"": {"handlers": ["default"], "level": "DEBUG", "propagate": False}},  # root logger
         }
     )
+    return logpath
+
+
+def cleanup_log(logpath: str = ""):
+    """
+    Delete the log file if it's empty
+    """
+    logpath = Path(logpath, "whispers.log")
+    if not logpath.stat().st_size:
+        remove(logpath.as_posix())
 
 
 def debug(message: str = "") -> str:
