@@ -1,11 +1,11 @@
 import json
 import re
 from collections import namedtuple
-from difflib import SequenceMatcher
 from hashlib import md5
 from pathlib import Path
 from typing import Optional
 
+from Levenshtein import ratio
 from yaml import safe_load
 
 Secret = namedtuple("Secret", ["file", "line", "key", "value", "message", "severity"])
@@ -42,7 +42,26 @@ def similar_strings(a: str, b: str) -> float:
     """
     a = simple_string(a).replace("_", "")
     b = simple_string(b).replace("_", "")
-    return SequenceMatcher(None, a, b).ratio()
+    return ratio(a, b)
+
+
+def string_is_quoted(value: str) -> bool:
+    """
+    Checks if the value is between single or double quotes
+    """
+    quotes = ('"', "'")
+    return value.startswith(quotes) and value.endswith(quotes)
+
+
+def string_is_function(value: str) -> bool:
+    """
+    Checks if the value resembles a function call
+    """
+    open_brackets = value.count("(")
+    close_brackets = value.count(")")
+    if open_brackets:
+        return open_brackets == close_brackets
+    return False
 
 
 def line_with_key_value(key: str, value: str, line: str) -> bool:
@@ -65,8 +84,6 @@ def line_begins_with_value(value: str, line: str) -> bool:
     """
     value_str = simple_string(value)
     line_str = simple_string(line)
-    if not line_str:
-        return False
     return value_str.startswith(line_str)
 
 
@@ -74,14 +91,12 @@ def find_line_number(filepath: Path, key: str, value: str) -> int:
     """
     Returns line number in file with given key and value
     """
-    if not key:
-        key = ""
     if not value:
-        value = ""
+        return 0
     value = value.split("\n")[0]
     value_line_number = 0
     for line_number, line in enumerate(filepath.open().readlines(), 1):
-        if not line:
+        if not strip_string(line):
             continue
         if line_with_key_value(key, value, line):
             return line_number
